# Monday changelog

## [0.1.2] - 2026-02-27
- Updated connector definition (YAML version 1.0.0)
- Source commit: 7bd29cad
- SDK version: 0.1.0

## [0.1.1] - 2026-02-27
- Updated connector definition (YAML version 1.0.0)
- Source commit: 39690c8e
- SDK version: 0.1.0

## [0.1.0] - 2026-02-26
- Updated connector definition (YAML version 1.0.0)
- Source commit: 9072a725
- SDK version: 0.1.0
